@@ -108,6 +108,7 @@ class FastEval:
             self.copy_ref()
             print('\n')
             self.prep_step()
+            self.gen_csv()
         else:
             print('Processing {} projects...\n'.format(len(self.submissions)))
             self.check_prep()
@@ -117,7 +118,8 @@ class FastEval:
         self.exte_step(self.comp_cmd, step='1_comp', label='Compiling')
         self.print_step_errors('1_comp')
         self.write_data()
-        #self.exte_step(self.exec_cmd, step='2_exec', label='Executing')
+        self.exte_step(self.exec_cmd, step='2_exec', label='Executing')
+        self.cleanup()
         self.print_step_errors('2_exec')
         self.write_data()
         self.export()
@@ -163,11 +165,13 @@ class FastEval:
             os.mkdir(raw_dir)
             for o in os.listdir(self.submissions[sub]['path']):
                 shutil.move(os.path.join(self.submissions[sub]['path'],o), raw_dir)
-            files = [os.path.join(raw_dir, o) for o in os.listdir(raw_dir)]
+            #files = [os.path.join(raw_dir, o) for o in os.listdir(raw_dir)]
+            files = [os.path.join(raw_dir, f) for root, _, files in os.walk(raw_dir) for f in files]
+            print(files)
             for f in files:
                 try:
                     shutil.unpack_archive(f, raw_dir)
-                    os.remove(f)
+                    #os.remove(f)
                 except shutil.ReadError:
                     print('Unpack ' + self.warn_str(f) + ' failed.')
     
@@ -233,7 +237,10 @@ class FastEval:
                 self.submissions[sub]['step'] = '1_comp'
     
         to_check = [sub for sub in self.submissions if self.submissions[sub]['step'] == '0_prep']
-        print('           ' + self.erro_str('{} fails.'.format(len(to_check))) + '\n')
+        if len(to_check) == 0:
+            print(f'           0 fails. {self.info_str("✓")}')
+        else:
+            print('           ' + self.erro_str('{} fails.'.format(len(to_check))) + '\n')
     def exte_step(self, cmd, step='1_comp', label='Compiling', timeout=10):
         to_exec = [sub for sub in self.submissions if self.submissions[sub]['step'] == step]
         print('{}  {} projects...'.format(label, len(to_exec)))
@@ -270,7 +277,6 @@ class FastEval:
             print(f'           0 fails. {self.info_str("✓")}')
         else:
             print('           ' + self.erro_str('{} fails.'.format(len(to_exec))) + '\n')
-        self.cleanup()
     
     def cleanup(self):
         for c in self.cleanup_cmd:
@@ -284,70 +290,72 @@ class FastEval:
         with open(outpath, 'w') as f:
             f.write("#+title: Rapport d'évaluation\n")
             for s in self.submissions:
-              step = self.submissions[s]['step']
-              f.write(f'** {s}\n')
+                step = self.submissions[s]['step']
+                steps = self.submissions[s]['steps']
+                f.write(f'** {s}\n')
     
-              # Section erreur prep
-              if step == '0_prep':
-                  f.write(f'*** Erreurs de préparation\n')
-                  for k, v in self.submissions[s]['steps']['0_prep'].items():
-                      f.write(f'{k} :\n')
-                      for i in v:
-                          f.write(f' - {i}\n')
-              # Section erreur comp
-              if step != '0_prep':
-                  ce = self.submissions[s]['steps']['1_comp']
-                  if ce:
-                      f.write(f'*** Erreurs de compilation\n')
-                  for k, v in ce.items():
-                      f.write(f'#+begin_src bash\n')
-                      f.write(f'{k}\n')
-                      f.write('#+end_src\n')
-                      f.write('\n#+name: stderror\n')
-                      f.write(f'#+begin_example\n')
-                      for line in v['stderr']:
-                          f.write(f'{line}\n')
-                      f.write('\n#+end_example\n')
+                # Section erreur prep
+                if steps['0_prep']:
+                    f.write(f'*** Erreurs de préparation\n')
+                    for k, v in steps['0_prep'].items():
+                        f.write(f'{k} :\n')
+                        for i in v:
+                            f.write(f' - {i}\n')
+                # Section erreur comp
+                if steps['1_comp']:
+                    usefull = False
+                    for v in steps['1_comp'].values():
+                        if 'stderr' in v:
+                            usefull = True
+                    if usefull:
+                        f.write(f'*** Erreurs de compilation\n')
+                        for k, v in steps['1_comp'].items():
+                            f.write(f'#+begin_src bash\n')
+                            f.write(f'{k}\n')
+                            f.write('#+end_src\n')
     
-              # Section avec code rendu
-              if step != '0_prep':
-                  f.write(f'*** code\n')
-                  for sf in self.required_files:
-                      f.write(f'**** {sf}\n')
-                      # Détermination du langage
-                      l = os.path.splitext(sf)[-1][1:]
-                      if l == 'py':
-                        l = python
-                      if l == 'sh':
-                        l = bash
-                      # Copie du code de l'étudiant
-                      f.write(f'#+begin_src {l}\n')
-                      with open(os.path.join(self.submissions[s]['path'], 'eval', sf), 'r') as cf:
+                            f.write('\n#+name: stderror\n')
+                            f.write(f'#+begin_example\n')
+                            for line in v['stderr']:
+                                f.write(f'{line}\n')
+                            f.write('\n#+end_example\n')
+    
+                # Section avec code rendu
+                if step != '0_prep':
+                    f.write(f'*** code\n')
+                    for sf in self.required_files:
+                        f.write(f'**** {sf}\n')
+                        # Détermination du langage
+                        l = os.path.splitext(sf)[-1][1:]
+                        if l == 'py':
+                            l = python
+                        if l == 'sh':
+                            l = bash
+                        # Copie du code de l'étudiant
+                        f.write(f'#+begin_src {l}\n')
+                        with open(os.path.join(self.submissions[s]['path'], 'eval', sf), 'r') as cf:
                             f.write(cf.read())
-                      f.write('\n#+end_src\n')
-    
-              # Section retour exécution
-              if step != '0_prep' and step != '1_comp':
-                  e = self.submissions[s]['steps']['2_exec']
-                  if e:
-                      f.write(f"*** Retours d'éxécution\n")
-                  for k, v in e.items():
-                      f.write(f'#+begin_src bash\n')
-                      f.write(f'{k}\n')
-                      f.write('#+end_src\n')
-                      if 'stderr' in v:
-                          f.write('\n#+name: stderror\n')
-                          f.write(f'#+begin_example\n')
-                          for line in v['stderr']:
-                              f.write(f'{line}\n')
-                          f.write('#+end_example\n')
-                      if 'stdout' in v:
-                          f.write('\n#+name: stdout\n')
-                          f.write(f'#+begin_example\n')
-                          for line in v['stdout']:
-                              f.write(f'{line}\n')
-                          f.write('#+end_example\n')
+                        f.write('\n#+end_src\n')
     
+                # Section retour exécution
+                if steps['2_exec']:
+                    f.write(f"*** Retours d'éxécution\n")
+                    for k, v in steps['2_exec'].items():
+                        f.write(f'#+begin_src bash\n')
+                        f.write(f'{k}\n')
+                    f.write('#+end_src\n')
+                    if 'stderr' in v:
+                        f.write('\n#+name: stderror\n')
+                        f.write(f'#+begin_example\n')
+                        for line in v['stderr']:
+                            f.write(f'{line}\n')
+                        f.write('#+end_example\n')
+                    if 'stdout' in v:
+                        f.write('\n#+name: stdout\n')
+                        f.write(f'#+begin_example\n')
+                        for line in v['stdout']:
+                            f.write(f'{line}\n')
+                        f.write('#+end_example\n')
         if self.export_to_html:
             self.gen_html()
     def gen_html(self, orgfile='readme.org', style='tango'):
@@ -360,6 +368,14 @@ class FastEval:
         else:
            print('Error while generating html')
     
+    def gen_csv(self):
+        outpath = os.path.join(self.workspace_path, 'notes.csv')
+        with open(outpath, 'w') as f:
+            names = [s for s in self.submissions]
+            names.sort()
+            print(names)
+            for n in names:
+                f.write(f'{n}, note\n')
     def next_step(self, step):
         if step == '0_prep':
             return '1_comp'
